@@ -19,10 +19,12 @@ test_that("sparkline construction",{
 			M <- sparkline( Theoph, 'Subject', 1, 'conc', xvar = NULL)
 			expect_equal(M[1,1], 1, check.names = FALSE)
 			expect_equal(class(M), 'sparkline')
+			expect_true(is.sparkline(M))
 			
 			M <- sparkline( Theoph, 'Subject', 1, 'conc', xvar = 'Time')
 			expect_equal(M[1,1], 0)
 			expect_equal(class(M), 'sparkline')
+			expect_true(is.sparkline(M))
 			
 		})
 
@@ -31,6 +33,7 @@ test_that("sparkline plotting",{
 			
 			
 			xy <- sparkline( Theoph, 'Subject', 1, 'conc', xvar = 'Time')
+			expect_true(is.sparkline(xy))
 		    plot(xy )	
 			
-		})
\ No newline at end of file
+		})
